Enum Request
Source pub enum Request {
Bond {
value: u128,
payee: RewardAccount,
},
BondExtra {
value: u128,
},
Unbond {
value: u128,
},
WithdrawUnbonded {
num_slashing_spans: u32,
},
Nominate {
targets: Vec<ActorId>,
},
Chill,
PayoutStakers {
validator_stash: ActorId,
era: u32,
},
Rebond {
value: u128,
},
SetPayee {
payee: RewardAccount,
},
ActiveEra,
}
Type that should be used to create a message to the staking built-in actor.
A partial mirror of the staking pallet interface. Not all extrinsics
are supported, more can be added as needed for real-world use cases.
Bond up to the value from the sender to self as the controller.
Add up to the value to the sender’s bonded amount.
Unbond up to the value to allow withdrawal after undonding period.
Withdraw unbonded chunks for which undonding period has elapsed.
Add sender as a nominator of targets or update the existing targets.
Declare intention to temporarily stop nominating while still having funds bonded.
Request stakers payout for the given era.
Rebond a portion of the sender’s stash scheduled to be unlocked.
Set the reward destination.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Attempt to deserialise the value from input.
Attempt to deserialize the value from input into a pre-allocated piece of memory.
Read more
Attempt to skip the encoded value from input.
Read more
Returns the fixed encoded size of the type.
Read more
If possible give a hint of expected size of the encoding.
Read more
Convert self to a slice and append it to the destination.
Convert self to an owned vector.
Convert self to a slice and then invoke the given closure with it.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
The type identifying for which type info is provided.
Read more
Returns the static type identifier for Self.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Decode
Self and consume all of the given input data.
Read more
Decode
Self and consume all of the given input data.
Read more
Decode
Self with the given maximum recursion depth and advance
input by the number of
bytes consumed.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
Return an encoding of Self prepended by given slice.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.