pub enum Request {
Bond {
value: u128,
payee: RewardAccount,
},
BondExtra {
value: u128,
},
Unbond {
value: u128,
},
WithdrawUnbonded {
num_slashing_spans: u32,
},
Nominate {
targets: Vec<ActorId>,
},
Chill,
PayoutStakers {
validator_stash: ActorId,
era: u32,
},
Rebond {
value: u128,
},
SetPayee {
payee: RewardAccount,
},
}Expand description
Type that should be used to create a message to the staking built-in actor.
A partial mirror of the staking pallet interface. Not all extrinsics
are supported, more can be added as needed for real-world use cases.
Variants
Bond
Bond up to the value from the sender to self as the controller.
BondExtra
Add up to the value to the sender’s bonded amount.
Unbond
Unbond up to the value to allow withdrawal after undonding period.
WithdrawUnbonded
Withdraw unbonded chunks for which undonding period has elapsed.
Nominate
Add sender as a nominator of targets or update the existing targets.
Chill
Declare intention to temporarily stop nominating while still having funds bonded.
PayoutStakers
Request stakers payout for the given era.
Rebond
Rebond a portion of the sender’s stash scheduled to be unlocked.
SetPayee
Set the reward destination.
Fields

payee: RewardAccountTrait Implementations
Sourceimpl Decode for Request
impl Decode for Request
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for Request
impl Encode for Request
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for Request
impl Eq for Request
impl StructuralPartialEq for Request