Enum Request

pub enum Request {
    Bond {
        value: u128,
        payee: RewardAccount,
    },
    BondExtra {
        value: u128,
    },
    Unbond {
        value: u128,
    },
    WithdrawUnbonded {
        num_slashing_spans: u32,
    },
    Nominate {
        targets: Vec<ActorId>,
    },
    Chill,
    PayoutStakers {
        validator_stash: ActorId,
        era: u32,
    },
    Rebond {
        value: u128,
    },
    SetPayee {
        payee: RewardAccount,
    },
}
Type that should be used to create a message to the staking built-in actor.

A [partial] mirror of the staking pallet interface. Not all extrinsics are supported, more can be added as needed for real-world use cases.

Variants



Bond

Bond up to the value from the sender to self as the controller.

Fields

value: u128


BondExtra

Add up to the value to the sender’s bonded amount.

Fields

value: u128


Unbond

Unbond up to the value to allow withdrawal after undonding period.

Fields

value: u128


WithdrawUnbonded

Withdraw unbonded chunks for which undonding period has elapsed.

Fields

num_slashing_spans: u32


Nominate

Add sender as a nominator of targets or update the existing targets.

Fields

targets: Vec<ActorId>


Chill

Declare intention to [temporarily] stop nominating while still having funds bonded.



PayoutStakers

Request stakers payout for the given era.

Fields

validator_stash: ActorId
era: u32


Rebond

Rebond a portion of the sender’s stash scheduled to be unlocked.

Fields

value: u128


SetPayee

Set the reward destination.

Fields